import React, { createContext, useContext, useReducer, useEffect } from 'react';

// Define the initial state and reducer
const initialState = {
  cart: [],
  cartDetails: null,
};

const cartReducer = (state, action) => {
  switch (action.type) {
    case 'SET_CART':
      return { ...state, cart: action.payload };

    case 'SET_CART_DETAILS':
      return { ...state, cartDetails: action.payload };

    // Add other cases as needed

    default:
      return state;
  }
};

// Create the context
const CartContext = createContext();

// Create the provider component
export const CartProvider = ({ children }) => {
  const [state, dispatch] = useReducer(cartReducer, initialState);

  // Action to set the cart data
  const setCart = (cartData) => {
    dispatch({ type: 'SET_CART', payload: cartData });
  };

  // Action to set cart details
  const setCartDetails = (details) => {
    dispatch({ type: 'SET_CART_DETAILS', payload: details });
  };

  // Add other actions as needed

  // Fetch cart details from the server
// Fetch cart details from the server
const fetchCartDetails = async () => {
  try {
    const token = localStorage.getItem('token');

    const response = await fetch(`${process.env.REACT_APP_API_URL}/cart/cart-details`, {
      method: 'GET',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    });    

    const data = await response.json();

    if (response.ok) {
      setCart(data.items); // Assuming the response has an 'items' array
      setCartDetails(data); // Set the cart details
    }
  } catch (error) {
    console.error('Error fetching cart details:', error);
  }
};


  // Fetch cart details when the component mounts or when the user changes
  useEffect(() => {
    const token = localStorage.getItem('token');
    if (token) {
      fetchCartDetails();
    }
  }, []); // The empty dependency array ensures that this effect runs only once when the component mounts

  return (
    <CartContext.Provider value={{ state, setCart, setCartDetails, fetchCartDetails }}>
      {children}
    </CartContext.Provider>
  );
};

// Custom hook to use the cart context
export const useCart = () => {
  const context = useContext(CartContext);
  if (!context) {
    throw new Error('useCart must be used within a CartProvider');
  }
  return context;
};
