// AddProductForm.js

import React, { useState } from 'react';
import { Form, Button } from 'react-bootstrap';

const AddProductForm = ({ onSave }) => {
  const [product, setProduct] = useState({
    name: '',
    description: '',
    price: 0,
    tags: '',
  });

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setProduct((prevProduct) => ({
      ...prevProduct,
      [name]: value,
    }));
  };

  const handleSave = () => {
    onSave(product);
    setProduct({
      name: '',
      description: '',
      price: 0,
      tags: '',
    });
  };

  return (
    <Form>
      <Form.Group controlId="formName">
        <Form.Label>Name</Form.Label>
        <Form.Control
          type="text"
          placeholder="Enter product name"
          name="name"
          value={product.name}
          onChange={handleInputChange}
        />
      </Form.Group>

      <Form.Group controlId="formDescription">
        <Form.Label>Description</Form.Label>
        <Form.Control
          as="textarea"
          rows={3}
          placeholder="Enter product description"
          name="description"
          value={product.description}
          onChange={handleInputChange}
        />
      </Form.Group>

      <Form.Group controlId="formPrice">
        <Form.Label>Price</Form.Label>
        <Form.Control
          type="number"
          placeholder="Enter product price"
          name="price"
          value={product.price}
          onChange={handleInputChange}
        />
      </Form.Group>

      <Form.Group controlId="formTags">
        <Form.Label>Tags</Form.Label>
        <Form.Control
          type="text"
          placeholder="Enter product tags"
          name="tags"
          value={product.tags}
          onChange={handleInputChange}
        />
      </Form.Group>

      <Button variant="primary" onClick={handleSave}>
        Save
      </Button>
    </Form>
  );
};

export default AddProductForm;
