import React, { useContext } from 'react';
import { Navbar, Nav, Container, Form, FormControl, Button } from 'react-bootstrap';
import { NavLink, Link } from 'react-router-dom';
import UserContext from '../UserContext';

export default function NavBar() {
  const { user } = useContext(UserContext);

  const handleNavLinkClick = () => {
    const navbarToggle = document.getElementById('basic-navbar-nav');
    if (navbarToggle) {
      navbarToggle.classList.remove('show');
    }
  };

  return (
    <Navbar bg="light" expand="lg" className="my-4 shadow-sm">
      <Container>
        <Navbar.Brand as={Link} to="" onClick={handleNavLinkClick}>
          iStore
        </Navbar.Brand>
        <Navbar.Toggle aria-controls="basic-navbar-nav" />
        <Navbar.Collapse id="basic-navbar-nav" onSelect={handleNavLinkClick}>
          <Nav className="mx-auto">
            <Form inline className="d-flex">
              <FormControl type="text" placeholder="Search" className="mr-sm-2" size="sm" />
              <Button className="ml-2">
                <i className="bi bi-search"></i>
              </Button>
            </Form>
          </Nav>
          <Nav className="ml-lg-auto">
            {user && user.id !== null ? (
              <>
                <Nav.Link as={NavLink} to="/profile" exact onClick={handleNavLinkClick}>
                  Profile
                </Nav.Link>
                <Nav.Link as={NavLink} to="/logout" exact onClick={handleNavLinkClick}>
                  Logout
                </Nav.Link>
                {user.isAdmin && (
                  <Nav.Link as={NavLink} to="/dashboard" exact onClick={handleNavLinkClick}>
                    Admin Dashboard
                  </Nav.Link>
                )}
                <Nav.Link as={NavLink} to="/cart" onClick={handleNavLinkClick}>
                  Cart
                </Nav.Link>
              </>
            ) : (
              <>
                <Nav.Link as={NavLink} to="/login" exact onClick={handleNavLinkClick}>
                  Login
                </Nav.Link>
                <Nav.Link as={NavLink} to="/register" exact onClick={handleNavLinkClick}>
                  Register
                </Nav.Link>
              </>
            )}
          </Nav>
        </Navbar.Collapse>
      </Container>
    </Navbar>
  );
}
