// ProductCatalog.js
import React, { useState, useEffect } from 'react';
import { Container, Col, Button, Row } from 'react-bootstrap';
import Slider from 'react-slick';
import { useMediaQuery } from 'react-responsive';
// import { toast, ToastContainer } from 'react-toastify';
import { Link } from 'react-router-dom'; // Import Link from react-router-dom
import 'react-toastify/dist/ReactToastify.css';
import 'slick-carousel/slick/slick.css';
import 'slick-carousel/slick/slick-theme.css';
import './productCatalog.css';
// import { jwtDecode } from 'jwt-decode';

const ProductCatalog = () => {
  const [taggedProducts, setTaggedProducts] = useState([]);
  const [activeFilter, setActiveFilter] = useState('onsale');
  const [error, setError] = useState(null);

  const isMobile = useMediaQuery({ maxWidth: 767 });

  useEffect(() => {
    const fetchTaggedProducts = async () => {
      try {
        const token = localStorage.getItem('token');

        const response = await fetch(
          `${process.env.REACT_APP_API_URL}/product/product-tag?tag=${activeFilter}`,
          {
            method: 'GET',
            headers: {
              Authorization: `Bearer ${token}`,
            },
          }
        );

        const data = await response.json();

        if (Array.isArray(data)) {
          setTaggedProducts(data);
          setError(null);
        } else {
          setError('Token is invalid. please login.');
        }
      } catch (error) {
        console.error('Error fetching tagged products:', error);
        setError('Error fetching tagged products. Please try again.');
      }
    };

    fetchTaggedProducts();
  }, [activeFilter]);

  // const handleAddToCart = async (productId) => {
  //   try {
  //     const token = localStorage.getItem('token');
      
  //     // Decode the token to get the userId
  //     const decodedToken = jwtDecode(token);
  //     const userId = decodedToken.userId;
  
  //     const response = await fetch(`${process.env.REACT_APP_API_URL}/cart/add-to-cart`, {
  //       method: 'POST',
  //       headers: {
  //         'Content-Type': 'application/json',
  //         Authorization: `Bearer ${token}`,
  //       },
  //       body: JSON.stringify({
  //         userId,
  //         productId,
  //         quantity: 1, // You can adjust the quantity as needed
  //       }),
  //     });
  
  //     const data = await response.json();
  
  //     if (response.ok) {
  //       // Product successfully added to the cart
  //       toast.success(`Product with ID ${productId} added to cart`, {
  //         position: 'bottom-right',
  //         autoClose: 2000,
  //         hideProgressBar: true,
  //         closeOnClick: true,
  //         pauseOnHover: true,
  //         draggable: true,
  //       });
  //     } else {
  //       // Handle error response from the server
  //       toast.error(`Failed to add product to cart: ${data.message}`, {
  //         position: 'bottom-right',
  //         autoClose: 2000,
  //         hideProgressBar: true,
  //         closeOnClick: true,
  //         pauseOnHover: true,
  //         draggable: true,
  //       });
  //     }
  //   } catch (error) {
  //     console.error('Error adding product to cart:', error);
  //     // Handle other errors, such as network issues
  //     toast.error('Error adding product to cart. Please try again later.', {
  //       position: 'bottom-right',
  //       autoClose: 2000,
  //       hideProgressBar: true,
  //       closeOnClick: true,
  //       pauseOnHover: true,
  //       draggable: true,
  //     });
  //   }
  // };
  
  
  const sliderSettings = {
    dots: true,
    infinite: true,
    speed: 500,
    slidesToShow: 1,
    slidesToScroll: 1,
    autoplay: true,
    autoplaySpeed: 3000,
  };

  return (
    <Container className="my-5 text-center">
      <h2>Top Products</h2>

      <div className="mb-3 d-flex justify-content-center">
        <Button
          variant={activeFilter === 'onsale' ? 'primary' : 'outline-primary'}
          onClick={() => setActiveFilter('onsale')}
          className="rounded-pill px-3 py-2 mx-2 btn-transition"
        >
          On Sale
        </Button>
        <Button
          variant={activeFilter === 'bestselling' ? 'primary' : 'outline-primary'}
          onClick={() => setActiveFilter('bestselling')}
          className="rounded-pill px-3 py-2 mx-2 btn-transition"
        >
          Best Selling
        </Button>
      </div>

      {isMobile ? (
        <Slider {...sliderSettings}>
          {error ? (
            <div>
              <p>{error}</p>
            </div>
          ) : (
            taggedProducts.map((product) => (
              <div key={product._id}>
                {/* Use Link to make product name clickable */}
                <Link
                  to={`/product/${product._id}`}
                  className="custom-link d-block text-decoration-none text-dark"
                >
                  <img
                    src={product.image || 'placeholder-image-url'}
                    alt={product.name}
                    className="img-fluid rounded"
                  />
                  <div className="mb-4" style={{ marginTop: '-70px', marginBottom: '-100px' }}>
                    <h6>{product.name}</h6>
                    <p>
                      {new Intl.NumberFormat('en-PH', {
                        style: 'currency',
                        currency: 'PHP',
                      }).format(product.price)}
                    </p>
                    {/* <Button
                      variant={activeFilter === 'bestselling' ? 'primary' : 'outline-primary'}
                      onClick={() => handleAddToCart(product._id)}
                      className="rounded-pill px-3 py-2 btn-transition"
                    >
                      Add to Cart
                    </Button> */}
                  </div>
                </Link>
              </div>
            ))
          )}
        </Slider>
      ) : (
        <Row>
          {error ? (
            <Col>
              <p>{error}</p>
            </Col>
          ) : (
            taggedProducts.map((product) => (
              <Col key={product._id} className="mb-2">
                <div>
                  {/* Use Link to make product name clickable */}
                  <Link
                    to={`/product/${product._id}`}
                    className="custom-link d-block text-decoration-none text-dark"
                  >
                    <img
                      src={product.image || 'placeholder-image-url'}
                      alt={product.name}
                      className="img-fluid rounded"
                    />
                    <h6>{product.name}</h6>
                    <p>
                      {new Intl.NumberFormat('en-PH', {
                        style: 'currency',
                        currency: 'PHP',
                      }).format(product.price)}
                    </p>
                    {/* <Button
                      variant={activeFilter === 'bestselling' ? 'primary' : 'outline-primary'}
                      onClick={() => handleAddToCart(product._id)}
                      className="rounded-pill px-3 py-2 btn-transition"
                    >
                      Add to Cart
                    </Button> */}
                  </Link>
                </div>
              </Col>
            ))
          )}
        </Row>
      )}
      {/* <ToastContainer /> */}
    </Container>
  );
};

export default ProductCatalog;