// components/ProtectedRoute.js

import React, { useEffect, useState } from 'react';
import { Route, Navigate, useLocation, useNavigate } from 'react-router-dom';
import { jwtDecode } from 'jwt-decode';

const isTokenValidFunction = (token) => {
  try {
    if (!token) {
      return false;
    }

    const decodedToken = jwtDecode(token);
    const currentTime = Date.now() / 1000;
    return decodedToken.exp > currentTime;
  } catch (error) {
    console.error('Error decoding token:', error);
    return false;
  }
};

const ProtectedRoute = ({ element: Element, ...rest }) => {
  const [isTokenValid, setIsTokenValid] = useState(true);
  const location = useLocation();
  const navigate = useNavigate();

  useEffect(() => {
    const checkTokenValidity = () => {
      const token = localStorage.getItem('token');
      const isValid = isTokenValidFunction(token);
      setIsTokenValid(isValid);

      if (!isValid && !location.state?.expired) {
        navigate('/login', { state: { expired: true } });
      }
    };

    checkTokenValidity();
  }, [location.state, navigate]);

  return (
    <Route
      {...rest}
      element={isTokenValid ? <Element /> : <Navigate to="/login" state={{ expired: true }} />}
    />
  );
};

export default ProtectedRoute;
