// TokenChecker.js
import { useEffect } from 'react';

const TOKEN_CHECK_INTERVAL = 30000; // 30 seconds in milliseconds

const TokenChecker = ({ setUser, unsetUser }) => {
  useEffect(() => {
    const checkTokenExpiration = async () => {
      const token = localStorage.getItem('token');
      const lastCheckTimestamp = localStorage.getItem('lastTokenCheck');

      if (token) {
        // Check if enough time has passed since the last token check
        const currentTime = new Date().getTime();
        if (lastCheckTimestamp && currentTime - lastCheckTimestamp < TOKEN_CHECK_INTERVAL) {
          return;
        }

        try {
          const response = await fetch(`${process.env.REACT_APP_API_URL}/user/details`, {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          });

          if (response.ok) {
            const data = await response.json();

            if (typeof data._id !== 'undefined') {
              setUser({
                id: data._id,
                isVerified: data.isVerified,
                isAdmin: data.isAdmin,
              });
            } else {
              setUser({
                id: null,
                isVerified: null,
                isAdmin: null,
              });
              unsetUser();
            }
          } else {
            // Handle token expiration by redirecting to the login page or the expired token page
            window.location.href = '/token-expired'; // Change this line as needed
          }
        } catch (error) {
          console.error('Error during token check:', error);
        }

        // Update the last check timestamp in local storage
        localStorage.setItem('lastTokenCheck', currentTime);
      }
    };

    // Call the token check function
    checkTokenExpiration();

    // Set up an interval for periodic token checks (adjust as needed)
    const intervalId = setInterval(checkTokenExpiration, TOKEN_CHECK_INTERVAL);

    // Cleanup: clear the interval when the component is unmounted
    return () => clearInterval(intervalId);
  }, [setUser, unsetUser]);

  // The rest of your component logic goes here...
  // Note: You don't need a return statement here.
};

export default TokenChecker;
