import React, { useState, useEffect } from 'react';
import { Container, Row, Col, Table, Button } from 'react-bootstrap';
import { jwtDecode } from 'jwt-decode';

const CheckoutPage = () => {
  const [orders, setOrders] = useState([]);

  useEffect(() => {
    // Fetch orders when the component mounts
    fetchOrders();
  }, []);

  const fetchOrders = async () => {
    try {
      const token = localStorage.getItem('token');
      const decoded = jwtDecode(token);
      const response = await fetch(`${process.env.REACT_APP_API_URL}/order/get-order`, {
        method: 'POST',
        headers: {
          Authorization: `Bearer ${token}`,
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          userId: decoded.userId,
        }),
      });

      if (!response.ok) {
        throw new Error('Failed to fetch orders');
      }

      const data = await response.json();
      setOrders(data.orderedProducts || []);
    } catch (error) {
      console.error('Error fetching orders:', error);
      // Handle error, show a message, etc.
    }
  };

  return (
    <Container className="my-5">
      <h2 className="text-center">Checkout</h2>
      {/* Display orders in a table */}
      <Row>
        <Col>
          <Table striped bordered hover>
            <thead>
              <tr>
                <th className="text-left">Product</th>
                <th className="text-left">Quantity</th>
                <th className="text-left">Price</th>
              </tr>
            </thead>
            <tbody>
              {orders.map((order) => (
                <tr key={order.productId}>
                  <td className="text-left">{order.productName}</td>
                  <td className="text-left">{order.quantity}</td>
                  <td className="text-left">{order.price}</td>
                </tr>
              ))}
            </tbody>
          </Table>
        </Col>
      </Row>
      <Row className="justify-content-end">
        <Col xs="auto">
          <Button variant="primary">Confirm and Pay</Button>
        </Col>
      </Row>
    </Container>
  );
};

export default CheckoutPage;
