// Profile.js
import React, { useContext, useEffect, useState } from 'react';
import { Row, Col, Button, Container } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import UserContext from '../UserContext';
import { Navigate } from 'react-router-dom';

export default function Profile() {
  const { user } = useContext(UserContext);
  const [profileData, setProfileData] = useState(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchUserProfile = async () => {
      try {
        if (user && user.id) {
          const token = localStorage.getItem('token');

          const response = await fetch(
            `${process.env.REACT_APP_API_URL}/user/details`,
            {
              method: 'GET',
              headers: {
                Authorization: `Bearer ${token}`,
              },
            }
          );

          if (response.ok) {
            const data = await response.json();
            setProfileData(data);
          } else {
            console.error('Failed to fetch user profile:', response.status);
          }
        }
      } catch (error) {
        console.error('Error fetching user profile:', error);
      } finally {
        setLoading(false);
      }
    };

    fetchUserProfile();
  }, [user]);

  if (!user || user.id === null) {
    return <Navigate to="/" />;
  }

  return (
    <Container>
    <Row>
      <Col md={6} className="shadow-sm p-5 bg-white">
        <h1 className="my-5">Profile</h1>
        {loading ? (
          <p>Loading profile...</p>
        ) : profileData ? (
          <>
            <h2 className="mt-3">
              {profileData.firstName} {profileData.lastName}
            </h2>
            <hr />
            <p>Email: {profileData.email}</p>
            <p>Mobile Number: {profileData.mobileNo}</p>
            <p>Account Type: {profileData.isAdmin ? 'Admin' : 'User'}</p>
            <h3>Orders</h3>
            {profileData.orderedProducts.length > 0 ? (
              <ul>
                {profileData.orderedProducts.map((order, index) => (
                  <li key={index}>
                    Order {index + 1}: {order.totalAmount}
                  </li>
                ))}
              </ul>
            ) : (
              <p>No orders yet.</p>
            )}
            <Link to="/update-profile">
              <Button variant="primary">Update Profile</Button>
            </Link>
          </>
        ) : (
          <p>No profile data available.</p>
        )}
      </Col>
    </Row>
    </Container>
  );
}
