import React from 'react';
import { Button } from 'react-bootstrap';
import Swal from 'sweetalert2';

export default function ArchiveCourse({ course, fetchData, isActive }) {

    
    const archiveToggle = (courseId) => {
        fetch(`${process.env.REACT_APP_API_URL}/courses/${courseId}/archive`, {
            method: 'PUT',
            headers: {
                'Content-Type': 'application/json',
                Authorization: `Bearer ${localStorage.getItem('token')}`
            }
        })
        .then(res => res.json())
        .then(data => {
            console.log(data);
    
            if (!data.success) {
                Swal.fire({
                    title: 'Success!',
                    icon: 'success',
                    text: 'Course Successfully Archived'
                });
                fetchData(); // Ensure it fetches the updated data
            } else {
                Swal.fire({
                    title: 'Error!',
                    icon: 'error',
                    text: 'Please try again'
                });
                fetchData();
            }
        });
    };
    
    

    const activateToggle = (courseId) => {
        fetch(`${ process.env.REACT_APP_API_URL}/courses/${courseId}/activate`, {
            method: 'PUT',
            headers: {
                'Content-Type': 'application/json',
                Authorization: `Bearer ${localStorage.getItem('token')}`
            }
        })
        .then(res => res.json())
        .then(data => {
            console.log(data);
            if (!data.success) {
                Swal.fire({
                    title: 'Success!',
                    icon: 'success',
                    text: 'Course Successfully Activated'
                });
                fetchData();
            } else {
                Swal.fire({
                    title: 'Error!',
                    icon: 'error',
                    text: ' Please try again'
                });
                fetchData();
            }
        });
    };

    return (
        <>
            {isActive ? (
                <Button variant="danger" size="sm" onClick={() => archiveToggle(course)}>
                    Archive
                </Button>
            ) : (
                <Button variant="success" size="sm" onClick={() => activateToggle(course)}>
                    Activate
                </Button>
            )}
        </>
    );
}
